EXPORTS
	?findDllMethod@@YAP6APAXXZPBD@Z @ 1 NONAME ; void * (*)(void) findDllMethod(char const *)
	?isActive@L2CapPushServerConnection@bluetooth@java@@QAE_NXZ @ 2 NONAME ; bool java::bluetooth::L2CapPushServerConnection::isActive(void)
	?open@L2CapPushServerConnection@bluetooth@java@@UAEXPAVConnectionListener@push@3@@Z @ 3 NONAME ; void java::bluetooth::L2CapPushServerConnection::open(class java::push::ConnectionListener *)
	?setFilter@L2CapPushServerConnection@bluetooth@java@@UAEXABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 4 NONAME ; void java::bluetooth::L2CapPushServerConnection::setFilter(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?getServiceRecordHandle@L2CAPServerConnection@bluetooth@java@@QAEPAVServiceRecord@23@XZ @ 5 NONAME ; class java::bluetooth::ServiceRecord * java::bluetooth::L2CAPServerConnection::getServiceRecordHandle(void)
	?initializeServiceRecord@L2CAPServerConnection@bluetooth@java@@QAEHHAAVTUUID@@AAVTDesC8@@@Z @ 6 NONAME ; int java::bluetooth::L2CAPServerConnection::initializeServiceRecord(int, class TUUID &, class TDesC8 &)
	?isMultipleSrvConnAllowed@BtL2CapServerConnectionFactory@bluetooth@java@@UAE_NXZ @ 7 NONAME ; bool java::bluetooth::BtL2CapServerConnectionFactory::isMultipleSrvConnAllowed(void)
	??1BtL2CapServerConnectionFactory@bluetooth@java@@UAE@XZ @ 8 NONAME ; java::bluetooth::BtL2CapServerConnectionFactory::~BtL2CapServerConnectionFactory(void)
	?initializeServiceRecord@L2CAPServerConnection@bluetooth@java@@QAEHHV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 9 NONAME ; int java::bluetooth::L2CAPServerConnection::initializeServiceRecord(int, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >)
	?GetServerPSM@L2CAPServerConnection@bluetooth@java@@QAEHXZ @ 10 NONAME ; int java::bluetooth::L2CAPServerConnection::GetServerPSM(void)
	?asyncAccept@L2CAPServerConnection@bluetooth@java@@QAEHPAVBluetoothPushEventListener@23@PAVBtUrlParams@23@@Z @ 11 NONAME ; int java::bluetooth::L2CAPServerConnection::asyncAccept(class java::bluetooth::BluetoothPushEventListener *, class java::bluetooth::BtUrlParams *)
	?create@BtL2CapServerConnectionFactory@bluetooth@java@@UAEPAVServerConnection@push@3@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 12 NONAME ; class java::push::ServerConnection * java::bluetooth::BtL2CapServerConnectionFactory::create(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?getFactory@BtL2CapServerConnectionFactory@bluetooth@java@@SAAAV123@XZ @ 13 NONAME ; class java::bluetooth::BtL2CapServerConnectionFactory & java::bluetooth::BtL2CapServerConnectionFactory::getFactory(void)
	?getFilter@L2CapPushServerConnection@bluetooth@java@@UBE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 14 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::L2CapPushServerConnection::getFilter(void) const
	?isConnectionAccepted@L2CapPushServerConnection@bluetooth@java@@QAE_NXZ @ 15 NONAME ; bool java::bluetooth::L2CapPushServerConnection::isConnectionAccepted(void)
	?getServerObject@L2CapPushServerConnection@bluetooth@java@@QAEPAVL2CAPServerConnection@23@XZ @ 16 NONAME ; class java::bluetooth::L2CAPServerConnection * java::bluetooth::L2CapPushServerConnection::getServerObject(void)
	??1L2CapPushServerConnection@bluetooth@java@@UAE@XZ @ 17 NONAME ; java::bluetooth::L2CapPushServerConnection::~L2CapPushServerConnection(void)
	??0L2CAPServerConnection@bluetooth@java@@QAE@PAVBluetoothFunctionServer@12@@Z @ 18 NONAME ; java::bluetooth::L2CAPServerConnection::L2CAPServerConnection(class java::bluetooth::BluetoothFunctionServer *)
	??0BtL2CapServerConnectionFactory@bluetooth@java@@QAE@XZ @ 19 NONAME ; java::bluetooth::BtL2CapServerConnectionFactory::BtL2CapServerConnectionFactory(void)
	?openServer@L2CAPServerConnection@bluetooth@java@@QAEH_N000HH@Z @ 20 NONAME ; int java::bluetooth::L2CAPServerConnection::openServer(bool, bool, bool, bool, int, int)
	?ServerOpen@L2CAPServerConnection@bluetooth@java@@QAEHHHHHHH@Z @ 21 NONAME ; int java::bluetooth::L2CAPServerConnection::ServerOpen(int, int, int, int, int, int)
	?isListening@L2CapPushServerConnection@bluetooth@java@@QAE_NXZ @ 22 NONAME ; bool java::bluetooth::L2CapPushServerConnection::isListening(void)
	?unsetClearServiceClassBitsFlag@L2CapPushServerConnection@bluetooth@java@@QAEXXZ @ 23 NONAME ; void java::bluetooth::L2CapPushServerConnection::unsetClearServiceClassBitsFlag(void)
	?deleteServer@L2CapPushServerConnection@bluetooth@java@@QAEXXZ @ 24 NONAME ; void java::bluetooth::L2CapPushServerConnection::deleteServer(void)
	??1L2CAPServerConnection@bluetooth@java@@QAE@XZ @ 25 NONAME ; java::bluetooth::L2CAPServerConnection::~L2CAPServerConnection(void)
	?getConnectedClient@L2CapPushServerConnection@bluetooth@java@@QAEPAVBluetoothClientConnection@23@XZ @ 26 NONAME ; class java::bluetooth::BluetoothClientConnection * java::bluetooth::L2CapPushServerConnection::getConnectedClient(void)
	?close@L2CapPushServerConnection@bluetooth@java@@UAEXXZ @ 27 NONAME ; void java::bluetooth::L2CapPushServerConnection::close(void)
	?setCreatedByPush@L2CapPushServerConnection@bluetooth@java@@QAEXXZ @ 28 NONAME ; void java::bluetooth::L2CapPushServerConnection::setCreatedByPush(void)
	?isCreatedByPush@L2CapPushServerConnection@bluetooth@java@@QAE_NXZ @ 29 NONAME ; bool java::bluetooth::L2CapPushServerConnection::isCreatedByPush(void)
	?Accept@L2CAPServerConnection@bluetooth@java@@QAEJXZ @ 30 NONAME ; long java::bluetooth::L2CAPServerConnection::Accept(void)
	?unsetAcceptMonitor@L2CapPushServerConnection@bluetooth@java@@QAEXXZ @ 31 NONAME ; void java::bluetooth::L2CapPushServerConnection::unsetAcceptMonitor(void)
	??0L2CapPushServerConnection@bluetooth@java@@QAE@V?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 32 NONAME ; java::bluetooth::L2CapPushServerConnection::L2CapPushServerConnection(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> >)
	?restorePersistentRecord@L2CAPServerConnection@bluetooth@java@@QAEHXZ @ 33 NONAME ; int java::bluetooth::L2CAPServerConnection::restorePersistentRecord(void)
	?setAcceptMonitor@L2CapPushServerConnection@bluetooth@java@@QAEXPAVMonitor@util@3@@Z @ 34 NONAME ; void java::bluetooth::L2CapPushServerConnection::setAcceptMonitor(class java::util::Monitor *)
	?createSrvConnObj@BtL2CapServerConnectionFactory@bluetooth@java@@UAEPAVServerConnection@push@3@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@0@Z @ 35 NONAME ; class java::push::ServerConnection * java::bluetooth::BtL2CapServerConnectionFactory::createSrvConnObj(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &, class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?getUri@L2CapPushServerConnection@bluetooth@java@@UBE?AV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@XZ @ 36 NONAME ; class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > java::bluetooth::L2CapPushServerConnection::getUri(void) const

